"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _storage = _interopRequireDefault(require("./storage"));

class File {
  constructor(key, storage) {
    this.key = key;
    this.storage = storage;
    this.file = {
      body: ""
    };
    this.bodyLoaded = false;
    this.metaLoaded = false;
  }
  /**
   * Get file storage
   */


  getStorage() {
    return this.storage;
  }
  /**
   * Get file key
   */


  getKey() {
    return this.key;
  }
  /**
   * Get public file URL
   */


  getUrl() {
    return this.storage.getURL(this.key);
  }
  /**
   * Get file body
   */


  async getBody(options) {
    if (!this.bodyLoaded) {
      this.file = await this.storage.getFile(this.key, options);
      this.bodyLoaded = true;
      this.metaLoaded = true;
    }

    return this.file.body;
  }
  /**
   * Get file meta
   */


  async getMeta() {
    if (!this.metaLoaded) {
      this.file.meta = await this.storage.getMeta(this.key);
      this.metaLoaded = true;
    }

    return this.file.meta;
  }
  /**
   * Set file contents (writes contents to storage)
   */


  setBody(data) {
    this.file.body = data;
    this.bodyLoaded = true;
  }
  /**
   * Set file meta
   */


  setMeta(meta) {
    this.file.meta = meta;
    this.metaLoaded = true;
  }
  /**
   * Get time modified
   */


  getTimeModified() {
    return this.storage.getTimeModified(this.key);
  }
  /**
   * Rename a file
   */


  rename(newKey) {
    return this.storage.rename(this.key, newKey);
  }
  /**
   * Delete a file
   */


  delete() {
    return this.storage.delete(this.key);
  }
  /**
   * Save file (call `setFile` on Storage instance)
   */


  async save() {
    this.key = await this.storage.setFile(this.key, this.file);
    return true;
  }
  /**
   * Get absolute file path.
   * If storage driver does not support absolute paths (cloud storage), returns file key
   *
   * @return string
   */


  getAbsolutePath() {
    return this.storage.getAbsolutePath(this.key);
  }
  /**
   * Get file size in bytes
   */


  getSize() {
    return this.storage.getSize(this.key);
  }
  /**
   * Get content type
   */


  getContentType(key) {
    return this.storage.getContentType(key);
  }

}

exports.default = File;
//# sourceMappingURL=file.js.map